'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var helper = require('@tarojs/helper');
var shared = require('@tarojs/shared');

var index = (ctx) => {
    const { framework } = ctx.initialConfig;
    if (framework !== 'react' || !getReactPath())
        return;
    ctx.modifyWebpackChain(({ chain, webpack }) => {
        setDefinePlugin(chain, webpack);
        console.log(helper.chalk.blue('✨ 逮到一个使用taro-hooks的小可爱~ \n 当前使用的框架是: React'));
        if (process.env.TARO_ENV === 'h5') {
            chain.merge({
                module: {
                    rule: {
                        'process-import-taro-hooks': {
                            test: /taro-h5[\\/]dist[\\/]index/,
                            loader: require.resolve('./api-loader'),
                        },
                    },
                },
            });
        }
        // MultiPlatformPlugin
        chain.resolve.plugin('MultiPlatformPlugin').tap((args) => {
            const needConcat = needConcatArgs();
            if (!needConcat) {
                args[2]['include'] = ['taro-hooks'];
                return args;
            }
            else {
                return [
                    ...args,
                    {
                        include: ['taro-hooks'],
                    },
                ];
            }
        });
    });
    if (process.env.TARO_ENV === 'weapp') {
        ctx.registerMethod({
            name: 'onSetupClose',
            fn(platform) {
                const pluginRuntimePath = '@taro-hooks/plugin-react/dist/runtime';
                const runtimePath = platform.runtimePath;
                if (shared.isArray(runtimePath)) {
                    runtimePath.push(pluginRuntimePath);
                }
                else if (shared.isString(runtimePath)) {
                    platform.runtimePath = [runtimePath, pluginRuntimePath];
                }
            },
        });
    }
};
function setDefinePlugin(chain, webpack) {
    chain.plugin('defined').use(webpack.DefinePlugin, [
        {
            'process.env.__TARO_HOOKS_REACT__': JSON.stringify(true),
        },
    ]);
}
// check version > 3.3
function needConcatArgs() {
    try {
        const pkgPath = require.resolve('@tarojs/taro/package.json', {
            paths: [process.cwd()],
        });
        return require(pkgPath).version?.replace(/\./gi, '') < 330;
    }
    catch (e) {
        return false;
    }
}
function getReactPath() {
    try {
        return require.resolve('react', {
            paths: [process.cwd()],
        });
    }
    catch (error) {
        console.log(helper.chalk.yellow('找不到 React. 请先安装。'));
        process.exit(1);
    }
}

exports["default"] = index;
exports.getReactPath = getReactPath;
//# sourceMappingURL=index.js.map
